@@ -25,7 +25,7 @@ if len(sys.argv) == 1:
 
 parser = argparse.ArgumentParser(description=__description__)
 parser.add_argument('-v', '--version', help="显示版本", action="store_true")
-parser.add_argument('-u', '--url', type=str, help='swagger API接口文档地址（必填)', required=True)
+parser.add_argument('-u', '--url', type=str, help='swagger API接口文档地址（必填)')
 parser.add_argument('-n', '--username', default=None, type=str, help='swagger用户名')
 parser.add_argument('-w', '--password', default=None, type=str, help='swagger密码')
 parser.add_argument('-p', '--path', default=None, type=str, help='API路径，用于单独转换指定API')
